==> owlapi-api-3.4.10-sources.jar: org/semanticweb/owlapi/util/Version.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.semanticweb.owlapi.util;

/** A simple utility class that describes the version of a piece of software e.g.
 * reasoner version. <br>
 * A version number is assumed to be the following format:
 * <b>major.minor.patch.build</b>.
 * 
 * @author Matthew Horridge, The University of Manchester, Information
 *         Management Group, Date: 09-Dec-2009 */
public class Version {
    private final int major;
    private final int minor;
    private final int patch;
    private final int build;

    /** @param major
     *            major version number
     * @param minor
     *            minor version number
     * @param patch
     *            patch number
     * @param build
     *            build number */
    public Version(int major, int minor, int patch, int build) {
        this.major = major;
        this.minor = minor;
        this.patch = patch;
        this.build = build;
    }

    /** @return major version */
    public int getMajor() {
        return major;
    }

    /** @return minor version */
    public int getMinor() {
        return minor;
    }

    /** @return patch version */
    public int getPatch() {
        return patch;
    }

    /** @return build version */
    public int getBuild() {
        return build;
    }
}

==> owlapi-api-3.5.0-sources.jar: org/semanticweb/owlapi/util/Version.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.semanticweb.owlapi.util;

/**
 * A simple utility class that describes the version of a piece of software e.g.
 * reasoner version. <br>
 * A version number is assumed to be the following format:
 * <b>major.minor.patch.build</b>.
 * 
 * @author Matthew Horridge, The University of Manchester, Information
 *         Management Group, Date: 09-Dec-2009
 */
public class Version {

    private final int major;
    private final int minor;
    private final int patch;
    private final int build;

    /**
     * @param major
     *        major version number
     * @param minor
     *        minor version number
     * @param patch
     *        patch number
     * @param build
     *        build number
     */
    public Version(int major, int minor, int patch, int build) {
        this.major = major;
        this.minor = minor;
        this.patch = patch;
        this.build = build;
    }

    /** @return major version */
    public int getMajor() {
        return major;
    }

    /** @return minor version */
    public int getMinor() {
        return minor;
    }

    /** @return patch version */
    public int getPatch() {
        return patch;
    }

    /** @return build version */
    public int getBuild() {
        return build;
    }
}
